@@ -138,11 +138,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraLocImmediately(Vector3d loc);
 
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置をセットします。
+     */
+    public void addCameraLoc(double x,double y,double z);
+
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置をセットします。
+     */
+    public void addCameraLoc(Vector3d loc);
+
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocImmediately(double x,double y,double z);
+
+    /**
+     * 現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocImmediately(Vector3d loc);
+
     /**
      * カメラの現在位置を返します。
      */
     public Vector3d getCameraLoc();
 
+    /**
+     * カメラの目標位置を返します。
+     * カメラは常に補完が効いているので最終的に到達する位置という意味です。
+     */
+    public Vector3d getCameraTargetLoc();
+
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -165,11 +191,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraQuatImmediately(Quat4d quat);
 
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraQuat(double x,double y,double z,double w);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraQuat(Quat4d quat);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatImmediately(double x,double y,double z,double w);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatImmediately(Quat4d quat);
+
     /**
      * カメラの現在の回転を返します。
      */
     public Quat4d getCameraQuat();
 
+    /**
+     * カメラの目標回転を返します。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Quat4d getCameraTargetQuat();
+
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -192,6 +244,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraRotImmediately(Vector3d rot);
 
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraRot(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraRot(Vector3d rot);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraRotImmediately(double x,double y,double z);
+
+    /**
+     * 現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraRotImmediately(Vector3d rot);
+
+    /**
+     * カメラの現在の回転を返します。
+     */
+    public Vector3d getCameraRot();
+
+    /**
+     * カメラの目標回転を返します。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Vector3d getCameraTargetRot();
+
     /**
      * カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
@@ -208,11 +291,27 @@ public interface A3CanvasInterface {
      */
     public void setCameraScaleImmediately(double s);
 
+    /**
+     * 現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率としてセットします。
+     */
+    public void mulCameraScale(double s);
+
+    /**
+     * 現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率として即時にセットします。
+     */
+    public void mulCameraScaleImmediately(double s);
+
     /**
      * カメラの拡大率を返します。
      */
     public double getCameraScale();
 
+    /**
+     * カメラの目標拡大率を返します。
+     * カメラは常に補完が効いているので最終的に到達する拡大率という意味です。
+     */
+    public double getCameraTargetScale();
+
     /**
      * ルックアットポイントを使って、カメラの回転を指定します。
      * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
@@ -302,8 +401,9 @@ public interface A3CanvasInterface {
 
     /**
      * ナビゲーションモードを指定します。
+     * 必要であればナビゲーションの初期化に必要なパラメータも渡してやります。
      */
-    public void setNavigationMode(NaviMode m);
+    public void setNavigationMode(NaviMode m,Object...params);
 
     /**
      * ナビゲーションの大まかなスピードを設定します。
@@ -515,11 +615,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraLocImmediately(Vector3d loc,int scene);
 
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置をセットします。
+     */
+    public void addCameraLoc(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置をセットします。
+     */
+    public void addCameraLoc(Vector3d loc,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocImmediately(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの位置に引数で与えられたベクトルを加えて新し位置を即時にセットします。
+     */
+    public void addCameraLocImmediately(Vector3d loc,int scene);
+
     /**
      * シーンを指定して、カメラの現在位置を返します。
      */
     public Vector3d getCameraLoc(int scene);
 
+    /**
+     * シーンを指定して、カメラの目標位置を返します。
+     * カメラは常に補完が効いているので最終的に到達する位置という意味です。
+     */
+    public Vector3d getCameraTargetLoc(int scene);
+
     /**
      * シーンを指定して、カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -542,11 +668,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraQuatImmediately(Quat4d quat,int scene);
 
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraQuat(double x,double y,double z,double w,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraQuat(Quat4d quat,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatImmediately(double x,double y,double z,double w,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraQuatImmediately(Quat4d quat,int scene);
+
     /**
      * シーンを指定して、カメラの現在の回転を返します。
      */
     public Quat4d getCameraQuat(int scene);
 
+    /**
+     * シーンを指定して、カメラの目標回転を返します。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Quat4d getCameraTargetQuat(int scene);
+
     /**
      * シーンを指定して、カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
      * 変ります。
@@ -569,6 +721,37 @@ public interface A3CanvasInterface {
      */
     public void setCameraRotImmediately(Vector3d rot,int scene);
 
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraRot(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成します。
+     */
+    public void mulCameraRot(Vector3d rot,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraRotImmediately(double x,double y,double z,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの回転に引数で与えられた回転を合成して即時に反映させます。
+     */
+    public void mulCameraRotImmediately(Vector3d rot,int scene);
+
+    /**
+     * シーンを指定して、カメラの現在の回転を返します。
+     */
+    public Vector3d getCameraRot(int scene);
+
+    /**
+     * シーンを指定して、カメラの目標回転を返します。
+     * カメラは常に補完が効いているので最終的に到達する回転という意味です。
+     */
+    public Vector3d getCameraTargetRot(int scene);
+
     /**
      * シーンを指定して、カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。拡大率がデフォルトの1.0の時は10cmより手前と100mより奥はクリッピングされて
@@ -585,11 +768,27 @@ public interface A3CanvasInterface {
      */
     public void setCameraScaleImmediately(double s,int scene);
 
+    /**
+     * シーンを指定して、現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率としてセットします。
+     */
+    public void mulCameraScale(double s,int scene);
+
+    /**
+     * シーンを指定して、現在のカメラの拡大率に引数で与えられた数値を掛け合せ新し拡大率として即時にセットします。
+     */
+    public void mulCameraScaleImmediately(double s,int scene);
+
     /**
      * シーンを指定して、カメラの拡大率を返します。
      */
     public double getCameraScale(int scene);
 
+    /**
+     * シーンを指定して、カメラの目標拡大率を返します。
+     * カメラは常に補完が効いているので最終的に到達する拡大率という意味です。
+     */
+    public double getCameraTargetScale(int scene);
+
     /**
      * シーンを指定し、ルックアットポイントを使ってカメラの回転を指定します。
      * 上方向ベクトルはそのカメラが存在するシーンのupperDirectionの
@@ -644,8 +843,9 @@ public interface A3CanvasInterface {
 
     /**
      * シーンを指定して、ナビゲーションモードを指定します。
+     * 必要であればナビゲーションの初期化に必要なパラメータも渡してやります。
      */
-    public void setNavigationMode(NaviMode m,int scene);
+    public void setNavigationMode(NaviMode m,int scene,Object...params);
 
     /**
      * シーンを指定して、ナビゲーションの大まかなスピードを設定します。
@@ -807,6 +1007,13 @@ public interface A3CanvasInterface {
      */
     public void setCameraInterpolateRatio(double ir);
 
+    /**
+     * Zバッファの処理方法を変更します．具体的には
+     * View.setDepthBufferFreezeTransparent(boolean)を
+     * そのまま呼び出します．
+     */
+    public void setDepthBufferFreezeTransparent(boolean b);
+
     //################################################################################
     //CameraInterface
     //################################################################################
