@@ -23,6 +23,8 @@ public abstract class A3Object {
     Object userData = null;
     boolean lockedA3 = false;
     boolean pickable = true;
+    boolean isEmphasized = false;
+    boolean isPolygonized = false;
     /**
      * 座標系の上を指定するための列挙型。
      */
@@ -269,6 +271,40 @@ public abstract class A3Object {
         setLocImmediately(new Vector3d(x,y,z));
     }
 
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void addLoc(Vector3d v) {
+        behavior.addLoc(v);
+    }
+
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void addLoc(double x, double y, double z) {
+        addLoc(new Vector3d(x,y,z));
+    }
+
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void addLocImmediately(Vector3d v) {
+        behavior.addLocImmediately(v);
+    }
+
+    /**
+     * 現在位置に引数で与えたベクトルを加えて新しい現在位置を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void addLocImmediately(double x,double y,double z) {
+        addLocImmediately(new Vector3d(x,y,z));
+    }
+
     /**
      * 現在位置を取得するためのメソッド。
      */
@@ -276,6 +312,15 @@ public abstract class A3Object {
         return behavior.getLoc();
     }
     
+    /**
+     * 目標位置を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetLocと同じだが、
+     * setEnableBehavior(true)の場合は目標座標を返す。
+     */
+    public final Vector3d getTargetLoc() {
+        return behavior.getTargetLoc();
+    }
+
     /**
      * 回転をセットするためのメソッド(四元数:Quat4d版)。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -310,6 +355,40 @@ public abstract class A3Object {
         setQuatImmediately(new Quat4d(x,y,z,w));
     }
 
+    /**
+     * 現在の回転に引数で与えた回転を合成するメソッド(四元数:Quat4d版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulQuat(Quat4d q) {
+        behavior.mulQuat(q);
+    }
+
+    /**
+     * 現在の回転に引数で与えた回転を合成するメソッド(四元数:x,y,z,w版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulQuat(double x, double y, double z, double w) {
+        mulQuat(new Quat4d(x,y,z,w));
+    }
+
+    /**
+     * 現在の回転に引数で与えた回転を即座に合成するメソッド(四元数:Quad4d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulQuatImmediately(Quat4d q) {
+        behavior.mulQuatImmediately(q);
+    }
+
+    /**
+     * 現在の回転に引数で与えた回転を即座に合成するメソッド(四元数:x,y,z,w版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulQuatImmediately(double x,double y,double z,double w) {
+        setQuatImmediately(new Quat4d(x,y,z,w));
+    }
+
     /**
      * 現在の回転を取得するためのメソッド(四元数:Quad4d版)。
      */
@@ -317,6 +396,15 @@ public abstract class A3Object {
         return behavior.getQuat();
     }
 
+    /**
+     * 目標回転を取得するためのメソッド(四元数:Quad4d版)。
+     * setEnableBehavior(false)の場合はgetQuatと同じだが、
+     * setEnableBehavior(true)の場合は目標回転を返す。
+     */
+    public final Quat4d getTargetQuat() {
+        return behavior.getTargetQuat();
+    }
+
     /**
      * 回転をセットするためのメソッド(オイラー角:Vector3d版)。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -359,14 +447,64 @@ public abstract class A3Object {
         setQuatImmediately(Util.euler2quat(x,y,z));
     }
 
+    /**
+     * 現在の回転に引数の回転を合成するためのメソッド(オイラー角:Vector3d版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRot(Vector3d rot) {
+        mulQuat(Util.euler2quat(rot));
+    }
+
+    /**
+     * 現在の回転に引数の回転を合成するためのメソッド(オイラー角:x,y,z版)。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRot(double x, double y,double z) {
+        mulQuat(Util.euler2quat(x,y,z));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角:Vector3d版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRotImmediately(Vector3d rot) {
+        mulQuatImmediately(Util.euler2quat(rot));
+    }
+
+    /**
+     * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角:x,y,z版)。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     * 座標変換はZ軸まわりの回転、Y軸まわりの回転、X軸まわりの回転
+     * の順番で適用されます。
+     */
+    public final void mulRotImmediately(double x,double y,double z) {
+        mulQuatImmediately(Util.euler2quat(x,y,z));
+    }
+
     /**
      * 現在の回転を取得するためのメソッド(オイラー角:Vector3d版)。
-     * 未実装！
      */
     public final Vector3d getRot() {
         return Util.quat2euler(getQuat());
     }
 
+    /**
+     * 目標回転を取得するためのメソッド(オイラー角:Vector3d版)。
+     * setEnableBehavior(false)の場合はgetRotと同じだが、
+     * setEnableBehavior(true)の場合は目標回転を返す。
+     */
+    public final Vector3d getTargetRot() {
+        return Util.quat2euler(getTargetQuat());
+    }
+    
     /**
      * Z軸の正の方向をオブジェクトの正面と見做し、それがlookAtで
      * 指定した座標に向くように回転をセットします。その時の計算に
@@ -426,6 +564,23 @@ public abstract class A3Object {
         behavior.setScaleImmediately(s);
     }
 
+    /**
+     * 現在の拡大率に引数の数値をかけてセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void mulScale(double s) {
+        behavior.mulScale(s);
+    }
+
+    /**
+     * 現在の拡大率に引数の数値をかけて即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void mulScaleImmediately(double s) {
+        behavior.mulScaleImmediately(s);
+    }
+
     /**
      * 現在の拡大率を取得するためのメソッド。
      */
@@ -433,6 +588,39 @@ public abstract class A3Object {
         return behavior.getScale();
     }
 
+    /**
+     * 目標拡大率を取得するためのメソッド。
+     * setEnableBehavior(false)の場合はgetScaleと同じだが、
+     * setEnableBehavior(true)の場合は目標拡大率を返す。
+     */
+    public final double getTargetScale() {
+        return behavior.getTargetScale();
+    }
+    
+    /**
+     * このオブジェクトのローカルな座標系のX軸がグローバルな
+     * 仮想空間の座標系ではどちらの方向になるのかを返します。
+     */
+    public final Vector3d getUnitVecX() {
+        return behavior.getUnitVecX();
+    }
+
+    /**
+     * このオブジェクトのローカルな座標系のY軸がグローバルな
+     * 仮想空間の座標系ではどちらの方向になるのかを返します。
+     */
+    public final Vector3d getUnitVecY() {
+        return behavior.getUnitVecY();
+    }
+
+    /**
+     * このオブジェクトのローカルな座標系のZ軸がグローバルな
+     * 仮想空間の座標系ではどちらの方向になるのかを返します。
+     */
+    public final Vector3d getUnitVecZ() {
+        return behavior.getUnitVecZ();
+    }
+
     /**
      * このオブジェクトのリソースを開放します。
      */
@@ -624,23 +812,64 @@ public abstract class A3Object {
      */
     public void emphasize() {
         component2DContainer.getA3VirtualUniverse().emphasize(this);
+        isEmphasized = true;
+        if (isPolygonized) {
+            unpolygonize();
+            isPolygonized = false;
+        }
     }
     /**
      * このA3Objectの強調表示をOFFにします。
      */
     public void unemphasize() {
         component2DContainer.getA3VirtualUniverse().unemphasize(this);
+        isEmphasized = false;
+    }
+    /**
+     * このA3Objectが強調表示されているかどうかを返します．
+     */
+    public boolean isEmphasized() {
+        return isEmphasized;
     }
     /**
      * このA3Objectをポリゴン表示にします。
      */
     public void polygonize() {
         component2DContainer.getA3VirtualUniverse().polygonize(this);
+        isPolygonized = true;
+        if (isEmphasized) {
+            unemphasize();
+            isEmphasized = false;
+        }
     }
     /**
      * このA3Objectをポリゴン表示をOFFにします。
      */
     public void unpolygonize() {
         component2DContainer.getA3VirtualUniverse().unpolygonize(this);
+        isPolygonized = false;
+    }
+    /**
+     * このA3Objectがポリゴン表示されているかどうかを返します．
+     */
+    public boolean isPolygonized() {
+        return isPolygonized;
+    }
+    /**
+     * このA3Objectの表示・非表示を切り替えます。
+     * ただし、この方法での非表示は表示サイズを0にするだけの
+     * 手抜きな実装による物なので、例えば音声や霧やスカイボックス
+     * などは非表示にできません。これらを完全に消すには
+     * A3CanvasInterface.del(A3Object)を使用して下さ。
+     */
+    public void setVisible(boolean b) {
+        behavior.setVisible(b);
+    }
+    /**
+     * Behaviorのスレッドで実行されるべき処理を
+     * 登録するためのメソッドです。
+     */
+    protected void runInBehavior(Runnable r) {
+        behavior.addRunnable(r);
     }
 }
