@@ -192,11 +192,36 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setCameraLocImmediately(loc);
     }
 
+    @Override
+    public void addCameraLoc(double x,double y,double z) {
+        subCamBehavior.addCameraLoc(x,y,z);
+    }
+
+    @Override
+    public void addCameraLoc(Vector3d loc) {
+        subCamBehavior.addCameraLoc(loc);
+    }
+
+    @Override
+    public void addCameraLocImmediately(double x,double y,double z) {
+        subCamBehavior.addCameraLocImmediately(x,y,z);
+    }
+
+    @Override
+    public void addCameraLocImmediately(Vector3d loc) {
+        subCamBehavior.addCameraLocImmediately(loc);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return subCamBehavior.getCameraLoc();
     }
 
+    @Override
+    public Vector3d getCameraTargetLoc() {
+        return subCamBehavior.getCameraTargetLoc();
+    }
+
     @Override
     public void setCameraQuat(double x,double y,double z,double w) {
         subCamBehavior.setCameraQuat(x,y,z,w);
@@ -217,11 +242,36 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setCameraQuatImmediately(quat);
     }
 
+    @Override
+    public void mulCameraQuat(double x,double y,double z,double w) {
+        subCamBehavior.mulCameraQuat(x,y,z,w);
+    }
+
+    @Override
+    public void mulCameraQuat(Quat4d quat) {
+        subCamBehavior.mulCameraQuat(quat);
+    }
+
+    @Override
+    public void mulCameraQuatImmediately(double x,double y,double z,double w) {
+        subCamBehavior.mulCameraQuatImmediately(x,y,z,w);
+    }
+
+    @Override
+    public void mulCameraQuatImmediately(Quat4d quat) {
+        subCamBehavior.mulCameraQuatImmediately(quat);
+    }
+
     @Override
     public Quat4d getCameraQuat() {
         return subCamBehavior.getCameraQuat();
     }
 
+    @Override
+    public Quat4d getCameraTargetQuat() {
+        return subCamBehavior.getCameraTargetQuat();
+    }
+
     @Override
     public void setCameraRot(double x,double y,double z) {
         subCamBehavior.setCameraRot(x,y,z);
@@ -242,6 +292,36 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setCameraRotImmediately(rot);
     }
 
+    @Override
+    public void mulCameraRot(double x,double y,double z) {
+        subCamBehavior.mulCameraRot(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRot(Vector3d rot) {
+        subCamBehavior.mulCameraRot(rot);
+    }
+
+    @Override
+    public void mulCameraRotImmediately(double x,double y,double z) {
+        subCamBehavior.mulCameraRotImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRotImmediately(Vector3d rot) {
+        subCamBehavior.setCameraRotImmediately(rot);
+    }
+
+    @Override
+    public Vector3d getCameraRot() {
+        return subCamBehavior.getCameraRot();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRot() {
+        return subCamBehavior.getCameraTargetRot();
+    }
+
     @Override
     public void setCameraScale(double s) {
         subCamBehavior.setCameraScale(s);
@@ -252,11 +332,26 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.setCameraScaleImmediately(s);
     }
 
+    @Override
+    public void mulCameraScale(double s) {
+        subCamBehavior.mulCameraScale(s);
+    }
+
+    @Override
+    public void mulCameraScaleImmediately(double s) {
+        subCamBehavior.mulCameraScaleImmediately(s);
+    }
+
     @Override
     public double getCameraScale() {
         return subCamBehavior.getCameraScale();
     }
 
+    @Override
+    public double getCameraTargetScale() {
+        return subCamBehavior.getCameraTargetScale();
+    }
+
     @Override
     public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up) {
         subCamBehavior.setCameraLookAtPoint(lookAt,up);
@@ -556,7 +651,7 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
 
     NaviMode naviMode = NaviMode.NONE;
     @Override
-    public void setNavigationMode(NaviMode m) {
+    public void setNavigationMode(NaviMode m,Object...params) {
         naviMode = m;
         if (naviMode == NaviMode.NONE)
             setA3Controller0(new NoneController());
@@ -569,9 +664,9 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         else if (naviMode == NaviMode.EDIT)
             setA3Controller0(new EditController());
         else if (naviMode == NaviMode.SIMPLE)
-            setA3Controller0(new SimpleController());
+            setA3Controller0(new SimpleController(params));
         else if (naviMode == NaviMode.CHASE)
-            setA3Controller0(new ChaseController());
+            setA3Controller0(new ChaseController(params));
     }
 
     @Override
@@ -963,6 +1058,17 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return 0;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public double getCameraTargetScale(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return 0;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1095,6 +1201,61 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLoc(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLoc(Vector3d loc, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLocImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLocImmediately(Vector3d loc, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetLoc(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1232,6 +1393,62 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuat(double x, double y, double z, double w, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuat(Quat4d quat, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuatImmediately(double x, double y, double z,
+            double w, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuatImmediately(Quat4d quat, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Quat4d getCameraTargetQuat(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1276,6 +1493,72 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRot(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRot(Vector3d rot, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRotImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRotImmediately(Vector3d rot, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraRot(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetRot(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1298,6 +1581,28 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraScale(double s, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraScaleImmediately(double s, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1382,7 +1687,7 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
      * 後のバージョンでは廃止する予定です。
      */
     @Override
-    public void setNavigationMode(NaviMode m, int scene) {
+    public void setNavigationMode(NaviMode m, int scene,Object...params) {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
@@ -1428,4 +1733,9 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
     public void setCameraInterpolateRatio(double ir) {
         subCamBehavior.setInterpolateRatio(ir);
     }
+
+    @Override
+    public void setDepthBufferFreezeTransparent(boolean b) {
+        view.setDepthBufferFreezeTransparent(b);
+    }
 }
