@@ -542,6 +542,13 @@ public class Action3D extends A3Object implements ActionObject {
         actionBehavior.setSoundGain(action,g);
     }
 
+    /**
+     * 全てのアクションのサウンドの音量を設定します。
+     */
+    public void setAllSoundGain(double g) {
+        actionBehavior.setAllSoundGain(g);
+    }
+
     /**
      * 現在選択されているアクションのサウンドの音量を取得します。
      */
@@ -795,4 +802,8 @@ public class Action3D extends A3Object implements ActionObject {
         if (actionBehavior!=null)
             actionBehavior.setSoundLocQuat(v,q);
     }
+    void setSoundTypeLocked() {
+        if (actionBehavior!=null)
+            actionBehavior.setSoundTypeLocked();
+    }
 }
