@@ -85,7 +85,7 @@ class Action3DData {
     HashMap<String,Motion> motions;
     HashMap<String,Object> sounds;
     BranchGroup allActionBranchGroup;
-    //Switch allActionSwitch;
+    Switch allActionSwitch;
 
     static BoundingSphere bounding = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
     //アクションの中のパーツのデータを保存しておくためのクラス
@@ -336,13 +336,14 @@ class Action3DData {
                     a3Sound.setSegno((float)segno);
                     a3Sound.setLoop(soundLoop);
                     A3SoundType type = null;
+                    a3Sound.setOffset(soundOffsetXYZ[0],soundOffsetXYZ[1],soundOffsetXYZ[2]);
+                    a3Sound.setDirection(soundDirectionXYZ[0],soundDirectionXYZ[1],soundDirectionXYZ[2]);
                     if (soundType.equals("BackgroundSound")) {
                         type = A3SoundType.BackgroundSound;
                         a3Sound.setType(type);
                     } else if (soundType.equals("ConeSound")) {
                         type = A3SoundType.ConeSound;
                         a3Sound.setType(type);
-                        a3Sound.setDirection(soundDirectionXYZ[0],soundDirectionXYZ[1],soundDirectionXYZ[2]);
                     } else {
                         type = A3SoundType.PointSound;
                         a3Sound.setType(type);
@@ -363,6 +364,15 @@ class Action3DData {
                 }
                 if (!exist) {
                     //syori
+                    //TransformGroup tgt = new TransformGroup();
+                    //tgt.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE);
+                    //tgt.setCapability(TransformGroup.ALLOW_CHILDREN_WRITE);
+                    //tgt.setCapability(TransformGroup.ALLOW_CHILDREN_EXTEND);
+                    //rootGroup.addChild(tgt);
+                    //2010,07/26：なぜかこの場合だけrootGroupへの追加になっていたので
+                    //他と同じようにtgに追加するように修正、それとこれもなぜか無意味なtgtと
+                    //いうのがあったけど削除。下の方もちょっとだけ修正。互換性がない変更だけど
+                    //やっぱりこのほうが良いと思う。
                     p = pHash.get(parts[i]);
                     BranchGroup bg = new BranchGroup();
                     bg.setCapability(BranchGroup.ALLOW_DETACH);
@@ -456,10 +466,10 @@ class Action3DData {
 
                     if (sabf.b!=null)
                         for (int j=0;j<sabf.b.length;j++) 
-                            rootGroup.addChild(sabf.b[j].cloneNode(false));
+                            bg.addChild(sabf.b[j].cloneNode(false));
                     if (sabf.f!=null)
                         for (int j=0;j<sabf.f.length;j++) 
-                            rootGroup.addChild(sabf.f[j].cloneNode(false));
+                            bg.addChild(sabf.f[j].cloneNode(false));
                 }
                 tgMap.put(children[i],tg);
                 construct(tg,children[i]);
@@ -626,7 +636,8 @@ class Action3DData {
             }
             a3 = (A3)u.unmarshal(cURL.openStream());
         } catch(Exception e) {
-            e.printStackTrace();
+            System.out.println("'catalog.xml'");
+            //e.printStackTrace();
             try {
                 URL cURL = null;
                 if (url.getProtocol().equals("file")) {
@@ -1084,7 +1095,9 @@ class Action3DData {
                 A3SoundType type = A3SoundType.PointSound;
                 float gain = 1.0f;
                 boolean loop = false;
-                A3Sound ss = soundSystem.load(soundURL.toString(), segno, type, gain, loop);
+                Vector3d offset = new Vector3d();
+                Vector3d dir = new Vector3d(0.0,0.0,1.0);
+                A3Sound ss = soundSystem.load(soundURL.toString(),segno,type,gain,loop,offset,dir);
                 sounds.put(filename,ss);
             }
         }
@@ -1098,18 +1111,18 @@ class Action3DData {
 
         allActionBranchGroup = new BranchGroup();
         allActionBranchGroup.setCapability(BranchGroup.ALLOW_DETACH);
-        allActionBranchGroup.setCapability(Group.ALLOW_CHILDREN_WRITE);  // <- Action3DでSwitchを使う場合には不要
-        allActionBranchGroup.setCapability(Group.ALLOW_CHILDREN_EXTEND); // <- Action3DでSwitchを使う場合には不要
+        //allActionBranchGroup.setCapability(Group.ALLOW_CHILDREN_WRITE);  // <- Action3DでSwitchを使う場合には不要
+        //allActionBranchGroup.setCapability(Group.ALLOW_CHILDREN_EXTEND); // <- Action3DでSwitchを使う場合には不要
 
-        //allActionSwitch = new Switch();
-        ////allActionSwitch.setCapability(Switch.ALLOW_PICKABLE_WRITE);
-        //allActionSwitch.setCapability(Switch.ALLOW_SWITCH_WRITE);
-        //for (int i=0;i<actions.length;i++) {
-        //    allActionSwitch.addChild(actions[i].rootGroup);
-        //}
-        allActionBranchGroup.addChild(actions[0].rootGroup);
-        //allActionBranchGroup.addChild(allActionSwitch);
-        //allActionSwitch.setWhichChild(0);
+        allActionSwitch = new Switch();
+        //allActionSwitch.setCapability(Switch.ALLOW_PICKABLE_WRITE);
+        allActionSwitch.setCapability(Switch.ALLOW_SWITCH_WRITE);
+        for (int i=0;i<actions.length;i++) {
+            allActionSwitch.addChild(actions[i].rootGroup);
+        }
+        //allActionBranchGroup.addChild(actions[0].rootGroup);
+        allActionBranchGroup.addChild(allActionSwitch);
+        allActionSwitch.setWhichChild(0);
     }
 
   //------------------------------------------------------------
