@@ -7,6 +7,7 @@ import javax.media.j3d.*;
 import javax.vecmath.*;
 
 import jp.sourceforge.acerola3d.a3.A3Object.BalloonDir;
+import jp.sourceforge.acerola3d.sound.*;
 
 /*
  * Action3DのためのBehavior。かなりのコードをこのBehavior
@@ -111,10 +112,10 @@ class ActionBehavior extends Behavior implements Cloneable {
     void doChangeAction(int newActionNo) {
         a3Data.actions[actionNo].stop();
         actionNo = newActionNo;
-        //a3Data.allActionSwitch.setWhichChild(actionNo);
-        Node n = a3Data.actions[actionNo].getRootGroup();
-        a3Data.allActionBranchGroup.removeAllChildren();
-        a3Data.allActionBranchGroup.addChild(n);
+        a3Data.allActionSwitch.setWhichChild(actionNo);
+        //Node n = a3Data.actions[actionNo].getRootGroup();
+        //a3Data.allActionBranchGroup.removeAllChildren();
+        //a3Data.allActionBranchGroup.addChild(n);
         a3Data.actions[actionNo].start();
         resetParameters();
         if (a3.isSelected3D()) {
@@ -515,6 +516,15 @@ class ActionBehavior extends Behavior implements Cloneable {
         a3Data.actions[actionNo].setSoundGain(g);
     }
 
+    /**
+     * 全てのアクションのサウンドの音量を設定します。
+     */
+    public void setAllSoundGain(double g) {
+        for (Action3DData.Action a : a3Data.actions) {
+            a.setSoundGain(g);
+        }
+    }
+
     /**
      * 現在選択されているアクションのサウンドの音量を取得します。
      */
@@ -630,4 +640,11 @@ class ActionBehavior extends Behavior implements Cloneable {
     void setSoundLocQuat(Vector3d v,Quat4d q) {
         a3Data.actions[actionNo].setSoundLocQuat(v,q);
     }
+    void setSoundTypeLocked() {
+        for (Action3DData.Action a : a3Data.actions) {
+            if (a.sound instanceof A3Sound) {
+                ((A3Sound)(a.sound)).setType(A3SoundType.BackgroundSound);
+            }
+        }
+    }
 }
