@@ -201,11 +201,36 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setCameraLocImmediately(loc);
     }
 
+    @Override
+    public void addCameraLoc(double x,double y,double z) {
+        subCamBehavior.addCameraLoc(x,y,z);
+    }
+
+    @Override
+    public void addCameraLoc(Vector3d loc) {
+        subCamBehavior.addCameraLoc(loc);
+    }
+
+    @Override
+    public void addCameraLocImmediately(double x,double y,double z) {
+        subCamBehavior.addCameraLocImmediately(x,y,z);
+    }
+
+    @Override
+    public void addCameraLocImmediately(Vector3d loc) {
+        subCamBehavior.addCameraLocImmediately(loc);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return subCamBehavior.getCameraLoc();
     }
 
+    @Override
+    public Vector3d getCameraTargetLoc() {
+        return subCamBehavior.getCameraTargetLoc();
+    }
+
     @Override
     public void setCameraQuat(double x,double y,double z,double w) {
         subCamBehavior.setCameraQuat(x,y,z,w);
@@ -226,11 +251,36 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setCameraQuatImmediately(quat);
     }
 
+    @Override
+    public void mulCameraQuat(double x,double y,double z,double w) {
+        subCamBehavior.mulCameraQuat(x,y,z,w);
+    }
+
+    @Override
+    public void mulCameraQuat(Quat4d quat) {
+        subCamBehavior.mulCameraQuat(quat);
+    }
+
+    @Override
+    public void mulCameraQuatImmediately(double x,double y,double z,double w) {
+        subCamBehavior.mulCameraQuatImmediately(x,y,z,w);
+    }
+
+    @Override
+    public void mulCameraQuatImmediately(Quat4d quat) {
+        subCamBehavior.mulCameraQuatImmediately(quat);
+    }
+
     @Override
     public Quat4d getCameraQuat() {
         return subCamBehavior.getCameraQuat();
     }
 
+    @Override
+    public Quat4d getCameraTargetQuat() {
+        return subCamBehavior.getCameraTargetQuat();
+    }
+
     @Override
     public void setCameraRot(double x,double y,double z) {
         subCamBehavior.setCameraRot(x,y,z);
@@ -251,6 +301,36 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setCameraRotImmediately(rot);
     }
 
+    @Override
+    public void mulCameraRot(double x,double y,double z) {
+        subCamBehavior.mulCameraRot(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRot(Vector3d rot) {
+        subCamBehavior.mulCameraRot(rot);
+    }
+
+    @Override
+    public void mulCameraRotImmediately(double x,double y,double z) {
+        subCamBehavior.mulCameraRotImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRotImmediately(Vector3d rot) {
+        subCamBehavior.mulCameraRotImmediately(rot);
+    }
+
+    @Override
+    public Vector3d getCameraRot() {
+        return subCamBehavior.getCameraRot();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRot() {
+        return subCamBehavior.getCameraTargetRot();
+    }
+
     @Override
     public void setCameraScale(double s) {
         subCamBehavior.setCameraScale(s);
@@ -261,11 +341,26 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         subCamBehavior.setCameraScaleImmediately(s);
     }
 
+    @Override
+    public void mulCameraScale(double s) {
+        subCamBehavior.mulCameraScale(s);
+    }
+
+    @Override
+    public void mulCameraScaleImmediately(double s) {
+        subCamBehavior.mulCameraScaleImmediately(s);
+    }
+
     @Override
     public double getCameraScale() {
         return subCamBehavior.getCameraScale();
     }
 
+    @Override
+    public double getCameraTargetScale() {
+        return subCamBehavior.getCameraTargetScale();
+    }
+
     @Override
     public void setCameraLookAtPoint(Vector3d lookAt,Vector3d up) {
         subCamBehavior.setCameraLookAtPoint(lookAt,up);
@@ -566,7 +661,7 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
 
     NaviMode naviMode = NaviMode.NONE;
     @Override
-    public void setNavigationMode(NaviMode m) {
+    public void setNavigationMode(NaviMode m,Object...params) {
         naviMode = m;
         if (naviMode == NaviMode.NONE)
             setA3Controller0(new NoneController());
@@ -579,9 +674,9 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         else if (naviMode == NaviMode.EDIT)
             setA3Controller0(new EditController());
         else if (naviMode == NaviMode.SIMPLE)
-            setA3Controller0(new SimpleController());
+            setA3Controller0(new SimpleController(params));
         else if (naviMode == NaviMode.CHASE)
-            setA3Controller0(new ChaseController());
+            setA3Controller0(new ChaseController(params));
         
     }
 
@@ -950,6 +1045,17 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return null;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetLoc(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -961,6 +1067,17 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return null;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Quat4d getCameraTargetQuat(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -972,6 +1089,17 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return 0;
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public double getCameraTargetScale(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return 0;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1104,6 +1232,50 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLoc(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLoc(Vector3d loc, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLocImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void addCameraLocImmediately(Vector3d loc, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1241,6 +1413,51 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuat(double x, double y, double z, double w, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuat(Quat4d quat, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuatImmediately(double x, double y, double z,
+            double w, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraQuatImmediately(Quat4d quat, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1285,6 +1502,72 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRot(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRot(Vector3d rot, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRotImmediately(double x, double y, double z, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraRotImmediately(Vector3d rot, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraRot(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public Vector3d getCameraTargetRot(int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        return null;
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1307,6 +1590,28 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         
     }
 
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraScale(double s, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
+    /**
+     * このメソッドはダミーのメソッドなので使用しないで下さい。
+     * アプリケーション側のプログラム互換性のために導入されましたが、
+     * 後のバージョンでは廃止する予定です。
+     */
+    @Override
+    public void mulCameraScaleImmediately(double s, int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+        
+    }
+
     /**
      * このメソッドはダミーのメソッドなので使用しないで下さい。
      * アプリケーション側のプログラム互換性のために導入されましたが、
@@ -1391,7 +1696,7 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
      * 後のバージョンでは廃止する予定です。
      */
     @Override
-    public void setNavigationMode(NaviMode m, int scene) {
+    public void setNavigationMode(NaviMode m, int scene,Object...params) {
         // TODO Version3系列ではこのメソッドが削除できるようにすべし。
         
     }
@@ -1438,4 +1743,9 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
     public void setCameraInterpolateRatio(double ir) {
         subCamBehavior.setInterpolateRatio(ir);
     }
+
+    @Override
+    public void setDepthBufferFreezeTransparent(boolean b) {
+        view.setDepthBufferFreezeTransparent(b);
+    }
 }
