@@ -83,6 +83,27 @@ class Scene implements Component2DContainerInterface {
      * A3Objectを追加して表示されるようにします。
      */
     public void add(A3Object a) {
+        add_OLD(a);
+    }
+    void add_NEW(A3Object a) {
+        if (a3Hash.containsKey(a))
+            return;
+        setAppearanceOverrideEnable((Group)a.getNode());
+        if (!a.getNode().isCompiled())
+            ((BranchGroup)a.getNode()).compile();
+        a.setComponent2DContainerInterface(this);
+        a.lockedA3=false;
+        a.init();
+        final A3BranchGroup bg = a.getA3BranchGroup();
+        Runnable r = new Runnable() {
+            public void run() {
+                mainGroup.addChild(bg);
+            }
+        };
+        universe.timerBehavior.addRunnable(r);
+        a3Hash.put(a,bg);
+    }
+    void add_OLD(A3Object a) {
         if (a3Hash.containsKey(a))
             return;
         setAppearanceOverrideEnable((Group)a.getNode());
@@ -120,9 +141,27 @@ class Scene implements Component2DContainerInterface {
      * します。
      */
     public void del(A3Object a) {
+        del_OLD(a);
+    }
+    void del_NEW(A3Object a) {
+        final BranchGroup bg = a3Hash.get(a);
+        if (bg==null)
+            return;
+        //a.unpolygonize();//gaha
+        Runnable r = new Runnable() {
+            public void run() {
+                bg.detach();
+            }
+        };
+        universe.timerBehavior.addRunnable(r);
+        a.dispose();
+        a3Hash.remove(a);
+    }
+    void del_OLD(A3Object a) {
         BranchGroup bg = a3Hash.get(a);
         if (bg==null)
             return;
+        //a.unpolygonize();//gaha
         bg.detach();
         a.dispose();
         a3Hash.remove(a);
@@ -143,28 +182,25 @@ class Scene implements Component2DContainerInterface {
         a3Hash.clear();
     }
 
-    BranchGroup backgroundBG = null;
+    A3Object backgroundA3;
     /**
      * 背景を表すA3Objectをセットします。
      */
     public void setBackground(A3Object a) {
-        if (backgroundBG!=null)
-            backgroundBG.detach();
-        Node n = a.getA3BranchGroup();
-        backgroundBG = new BranchGroup();
-        backgroundBG.setCapability(BranchGroup.ALLOW_DETACH);
-        backgroundBG.addChild(n);
-        mainGroup.addChild(backgroundBG);
-        background = a;
-        a.pickable = false;
+        if (a3Hash.containsKey(a))
+            del(a);
+        backgroundA3 = a;
+        a.setPickable(false);
+        add(a);
     }
 
     /**
      * 背景を削除します。
      */
     public void delBackground() {
-        if (backgroundBG!=null)
-            backgroundBG.detach();
+        if (backgroundA3==null)
+            return;
+        del(backgroundA3);
         background = null;
     }
 
@@ -286,12 +322,33 @@ class Scene implements Component2DContainerInterface {
         cameraNextV.set(loc);
     }
 
+    public void addCameraLoc(double x,double y,double z) {
+        cameraNextV.x += x;
+        cameraNextV.y += y;
+        cameraNextV.z += z;
+    }
+    public void addCameraLoc(Vector3d loc) {
+        cameraNextV.add(loc);
+    }
+    public void addCameraLocImmediately(double x,double y,double z) {
+        cameraNextV.x += x;
+        cameraNextV.y += y;
+        cameraNextV.z += z;
+        cameraNowV.set(cameraNextV);
+    }
+    public void addCameraLocImmediately(Vector3d loc) {
+        cameraNextV.add(loc);
+        cameraNowV.set(cameraNextV);
+    }
     /**
      * カメラの現在位置を返します。
      */
     public Vector3d getCameraLoc() {
         return new Vector3d(cameraNowV);
     }
+    public Vector3d getCameraTargetLoc() {
+        return new Vector3d(cameraNextV);
+    }
 
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
@@ -325,12 +382,29 @@ class Scene implements Component2DContainerInterface {
         cameraNextQ.set(quat);
     }
 
+    public void mulCameraQuat(double x,double y,double z,double w) {
+        cameraNextQ.mul(new Quat4d(x,y,z,w));
+    }
+    public void mulCameraQuat(Quat4d quat) {
+        cameraNextQ.mul(quat);
+    }
+    public void mulCameraQuatImmediately(double x,double y,double z,double w) {
+        cameraNextQ.mul(new Quat4d(x,y,z,w));
+        cameraNowQ.set(cameraNextQ);
+    }
+    public void mulCameraQuatImmediately(Quat4d quat) {
+        cameraNextQ.mul(quat);
+        cameraNowQ.set(cameraNextQ);
+    }
     /**
      * カメラの現在の回転を返します。
      */
     public Quat4d getCameraQuat() {
         return new Quat4d(cameraNowQ);
     }
+    public Quat4d getCameraTargetQuat() {
+        return new Quat4d(cameraNextQ);
+    }
 
     /**
      * カメラの回転を指定します。自動的に補完が働き滑らかにカメラの回転が
@@ -362,6 +436,24 @@ class Scene implements Component2DContainerInterface {
         setCameraQuatImmediately(Util.euler2quat(rot));
     }
 
+    public void mulCameraRot(double x,double y,double z) {
+        mulCameraQuat(Util.euler2quat(x,y,z));
+    }
+    public void mulCameraRot(Vector3d rot) {
+        mulCameraQuat(Util.euler2quat(rot));
+    }
+    public void mulCameraRotImmediately(double x,double y,double z) {
+        mulCameraQuatImmediately(Util.euler2quat(x,y,z));
+    }
+    public void mulCameraRotImmediately(Vector3d rot) {
+        mulCameraQuatImmediately(Util.euler2quat(rot));
+    }
+    public Vector3d getCameraRot() {
+        return Util.quat2euler(cameraNowQ);
+    }
+    public Vector3d getCameraTargetRot() {
+        return Util.quat2euler(cameraNextQ);
+    }
     /**
      * カメラの拡大率を指定します。自動的に補完が働き滑らかにカメラの拡大率が
      * 変ります。
@@ -378,12 +470,22 @@ class Scene implements Component2DContainerInterface {
         cameraNextS = s;
     }
 
+    public void mulCameraScale(double s) {
+        cameraNextS *= s;
+    }
+    public void mulCameraScaleImmediately(double s) {
+        cameraNextS *= s;
+        cameraNowS = cameraNextS;
+    }
     /**
      * カメラの拡大率を返します。
      */
     public double getCameraScale() {
         return cameraNowS;
     }
+    public double getCameraTargetScale() {
+        return cameraNextS;
+    }
 
     /**
      * ルックアットポイントを使って、カメラの回転を指定します。
@@ -473,7 +575,7 @@ class Scene implements Component2DContainerInterface {
     /**
      * ナビゲーションモードを指定します。
      */
-    public void setNavigationMode(NaviMode m) {
+    public void setNavigationMode(NaviMode m,Object...params) {
         naviMode = m;
         if (naviMode == NaviMode.NONE)
             setA3Controller0(new NoneController());
@@ -486,9 +588,9 @@ class Scene implements Component2DContainerInterface {
         else if (naviMode == NaviMode.EDIT)
             setA3Controller0(new EditController());
         else if (naviMode == NaviMode.SIMPLE)
-            setA3Controller0(new SimpleController());
+            setA3Controller0(new SimpleController(params));
         else if (naviMode == NaviMode.CHASE)
-            setA3Controller0(new ChaseController());
+            setA3Controller0(new ChaseController(params));
     }
 
     double naviSpeed = 1.0;
@@ -572,6 +674,11 @@ class Scene implements Component2DContainerInterface {
             return;
         a.setComponent2DContainerInterface(this);
         a.lockedA3=true;
+        if (a instanceof Action3D) {
+            ((Action3D)a).setSoundTypeLocked();
+        } else if (a instanceof A3Sounds) {
+            ((A3Sounds)a).setSoundTypeLocked();
+        }
         a.init();
         A3BranchGroup bg = a.getA3BranchGroup();
         cameraGroup.addChild(bg);
